==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ConfigurationServiceGitPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Property of git environment.
 * @property repositories Repositories of Application Configuration Service git property.
 */
public data class ConfigurationServiceGitPropertyArgs(
    public val repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs =
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder()
            .repositories(
                repositories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationServiceGitPropertyArgs].
 */
@PulumiTagMarker
public class ConfigurationServiceGitPropertyArgsBuilder internal constructor() {
    private var repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("gkybcrwdvgnfbmte")
    public suspend fun repositories(`value`: Output<List<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = value
    }

    @JvmName("updwmadhtrbeyvbh")
    public suspend fun repositories(vararg values: Output<ConfigurationServiceGitRepositoryArgs>) {
        this.repositories = Output.all(values.asList())
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("pbaialqcvbgdivox")
    public suspend fun repositories(values: List<Output<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = Output.all(values)
    }

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("ivltnmopjmewyptd")
    public suspend fun repositories(`value`: List<ConfigurationServiceGitRepositoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("nujtbkqsvghywaja")
    public suspend
    fun repositories(argument: List<suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("axbtpymskcnqinbh")
    public suspend fun repositories(
        vararg
        argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("vckqslixtxpcmphp")
    public suspend
    fun repositories(argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("dusftqkmqtstkixg")
    public suspend fun repositories(vararg values: ConfigurationServiceGitRepositoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    internal fun build(): ConfigurationServiceGitPropertyArgs = ConfigurationServiceGitPropertyArgs(
        repositories = repositories,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ConfigurationServiceGitPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Property of git environment.
 * @property repositories Repositories of Application Configuration Service git property.
 */
public data class ConfigurationServiceGitPropertyArgs(
    public val repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs =
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder()
            .repositories(
                repositories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationServiceGitPropertyArgs].
 */
@PulumiTagMarker
public class ConfigurationServiceGitPropertyArgsBuilder internal constructor() {
    private var repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("ghtaswkhyhnjcwah")
    public suspend fun repositories(`value`: Output<List<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = value
    }

    @JvmName("gnhppicftypsuhfy")
    public suspend fun repositories(vararg values: Output<ConfigurationServiceGitRepositoryArgs>) {
        this.repositories = Output.all(values.asList())
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("ghpgdlegferhjdpf")
    public suspend fun repositories(values: List<Output<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = Output.all(values)
    }

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("htdrjrddqktyprtb")
    public suspend fun repositories(`value`: List<ConfigurationServiceGitRepositoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("stxwwptafshohqcd")
    public suspend
    fun repositories(argument: List<suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("dkyvnqtprlocnwil")
    public suspend fun repositories(
        vararg
        argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("soghyamycepkvuvb")
    public suspend
    fun repositories(argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("mlyfekofnifhyatv")
    public suspend fun repositories(vararg values: ConfigurationServiceGitRepositoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    internal fun build(): ConfigurationServiceGitPropertyArgs = ConfigurationServiceGitPropertyArgs(
        repositories = repositories,
    )
}
